==> db4o_6.1.401~dfsg.orig.tar.gz: db4o-6.1/src/Db4objects.Db4o/Db4objects.Db4o/Foundation/SimpleTimer.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace Db4objects.Db4o.Foundation
{
	/// <exclude></exclude>
	public class SimpleTimer : Sharpen.Lang.IRunnable
	{
		private readonly Sharpen.Lang.IRunnable _runnable;

		private readonly int _interval;

		public volatile bool stopped = false;

		public SimpleTimer(Sharpen.Lang.IRunnable runnable, int interval, string name)
		{
			_runnable = runnable;
			_interval = interval;
			Sharpen.Lang.Thread thread = new Sharpen.Lang.Thread(this);
			thread.SetDaemon(true);
			thread.SetName(name);
			thread.Start();
		}

		public virtual void Stop()
		{
			stopped = true;
		}

		public virtual void Run()
		{
			while (!stopped)
			{
				Db4objects.Db4o.Foundation.Cool.SleepIgnoringInterruption(_interval);
				if (!stopped)
				{
					_runnable.Run();
				}
			}
		}
	}
}

==> db4o_6.1.604+dfsg.orig.tar.gz: db4o-6.1.604/src/Db4objects.Db4o/Db4objects.Db4o/Foundation/SimpleTimer.cs <==
/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace Db4objects.Db4o.Foundation
{
	/// <exclude></exclude>
	public sealed class SimpleTimer : Sharpen.Lang.IRunnable
	{
		private readonly Sharpen.Lang.IRunnable _runnable;

		private readonly int _interval;

		public volatile bool stopped = false;

		public SimpleTimer(Sharpen.Lang.IRunnable runnable, int interval, string name)
		{
			_runnable = runnable;
			_interval = interval;
			Sharpen.Lang.Thread thread = new Sharpen.Lang.Thread(this);
			thread.SetDaemon(true);
			thread.SetName(name);
			thread.Start();
		}

		public void Stop()
		{
			stopped = true;
		}

		public void Run()
		{
			while (!stopped)
			{
				Db4objects.Db4o.Foundation.Cool.SleepIgnoringInterruption(_interval);
				if (!stopped)
				{
					_runnable.Run();
				}
			}
		}
	}
}
